@@ -24,6 +24,7 @@
     StringPrototypeToUpperCase,
     StringPrototypeReplace,
     StringPrototypeCharCodeAt,
+    StringFromCharCode,
     Symbol,
     SymbolFor,
     SymbolToStringTag,
@@ -140,9 +141,11 @@
   }
 
   function unpaddedBase64(bytes) {
-    const binaryString = core.decode(bytes);
+    let binaryString = "";
+    for (let i = 0; i < bytes.length; i++) {
+      binaryString += StringFromCharCode(bytes[i]);
+    }
     const base64String = btoa(binaryString);
-
     return StringPrototypeReplace(base64String, /=/g, "");
   }
 
